@@ -5,6 +5,7 @@ Markdown cells, output, and metadata are ignored.
 """
 
 import json
+from collections import defaultdict
 from typing import TYPE_CHECKING, Dict, Iterator, List
 
 if TYPE_CHECKING:
@@ -12,9 +13,35 @@ if TYPE_CHECKING:
 
 CODE_SEPARATOR = "# %%"
 MAGIC = "# NBQAMAGIC"
+BLANK_SPACES = defaultdict(lambda: "\n\n")
+BLANK_SPACES["isort"] = "\n"
 
 
-def main(notebook: "Path", temp_python_file: "Path") -> Dict[int, str]:
+def _replace_magics(source: List[str]) -> Iterator[str]:
+    """
+    Comment out lines with magic commands.
+
+    If it's a script/bash cell, comment out the entire cell.
+
+    Parameters
+    ----------
+    source
+        Source from notebook cell.
+
+    Yields
+    ------
+    str
+        Line from cell, possibly commented out.
+    """
+    bash_cell = source and any(source[0].startswith(i) for i in ("%%script", "%%bash"))
+    for j in source:
+        if (j.startswith("!") or j.startswith("%")) or bash_cell:
+            yield f"{MAGIC}{j}"
+        else:
+            yield j
+
+
+def main(notebook: "Path", temp_python_file: "Path", command: str) -> Dict[int, str]:
     """
     Extract code cells from notebook and save them in temporary Python file.
 
@@ -24,6 +51,8 @@ def main(notebook: "Path", temp_python_file: "Path") -> Dict[int, str]:
         Jupyter Notebook third-party tool is being run against.
     temp_python_file
         Temporary Python file to save converted notebook in.
+    command
+        Third party tool which you're running on your notebook.
 
     Returns
     -------
@@ -40,36 +69,11 @@ def main(notebook: "Path", temp_python_file: "Path") -> Dict[int, str]:
     line_number = 0
     cell_number = 0
 
-    def _replace_magics(source: List[str]) -> Iterator[str]:
-        """
-        Comment out lines with magic commands.
-
-        If it's a script/bash cell, comment out the entire cell.
-
-        Parameters
-        ----------
-        source
-            Source from notebook cell.
-
-        Yields
-        ------
-        str
-            Line from cell, possibly commented out.
-        """
-        bash_cell = source and any(
-            source[0].startswith(i) for i in ("%%script", "%%bash")
-        )
-        for j in source:
-            if (j.startswith("!") or j.startswith("%")) or bash_cell:
-                yield f"{MAGIC}{j}"
-            else:
-                yield j
-
     for i in cells:
         if i["cell_type"] != "code":
             continue
         source = _replace_magics(i["source"])
-        parsed_cell = f"\n\n{CODE_SEPARATOR}\n{''.join(source)}\n"
+        parsed_cell = f"{BLANK_SPACES[command]}{CODE_SEPARATOR}\n{''.join(source)}\n"
         result.append(parsed_cell)
         split_parsed_cell = parsed_cell.splitlines()
         mapping = {
@@ -81,6 +85,6 @@ def main(notebook: "Path", temp_python_file: "Path") -> Dict[int, str]:
         cell_number += 1
 
     with open(str(temp_python_file), "w") as handle:
-        handle.write("".join(result)[len("\n\n") : -len("\n")])
+        handle.write("".join(result)[len(BLANK_SPACES[command]) : -len("\n")])
 
     return cell_mapping
